@@ -1,5 +1,6 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
+  Copyright (C) 2009 by Juan Carlos Torres <carlosdgtorres@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -37,6 +38,7 @@ class KMenu;
 class KPushButton;
 
 class QToolButton;
+class QLabel;
 
 
 class TabBar : public QWidget
@@ -55,7 +57,6 @@ class TabBar : public QWidget
         void addTab(int sessionId, const QString& title = 0);
         void removeTab(int sessionId = -1);
 
-        void renameTab(int sessionId = -1, const QString& newTitle = 0);
         void interactiveRename(int sessionId);
 
         void selectTab(int sessionId);
@@ -76,6 +77,10 @@ class TabBar : public QWidget
         void tabSelected(int sessionId);
         void tabClosed(int sessionId);
 
+        void requestTerminalHighlight(int terminalId);
+        void requestRemoveTerminalHighlight();
+        void tabContextMenuClosed();
+
 
     protected:
         virtual void resizeEvent(QResizeEvent*);
@@ -84,24 +89,43 @@ class TabBar : public QWidget
         virtual void keyPressEvent(QKeyEvent*);
         virtual void mousePressEvent(QMouseEvent*);
         virtual void mouseReleaseEvent(QMouseEvent*);
+        virtual void mouseMoveEvent(QMouseEvent*);
+        virtual void dragMoveEvent(QDragMoveEvent*);
+        virtual void dragEnterEvent(QDragEnterEvent*);
+        virtual void dragLeaveEvent(QDragLeaveEvent*);
+        virtual void dropEvent(QDropEvent*);
         virtual void mouseDoubleClickEvent(QMouseEvent*);
         virtual void contextMenuEvent(QContextMenuEvent*);
         virtual void leaveEvent(QEvent*);
 
 
     private slots:
-        void readyTabContextMenu();
         void readySessionMenu();
 
+        void contextMenuActionHovered(QAction* action);
+
         void closeTabButtonClicked();
 
+        void interactiveRenameDone();
+
 
     private:
         QString standardTabTitle();
         QString makeTabTitle(int number);
         int tabAt(int x);
 
+        void readyTabContextMenu();
+
         void updateMoveActions(int index);
+        void updateToggleActions(int sessionId);
+        void updateToggleKeyboardInputMenu(int sessionId = -1);
+
+        int drawButton(int x, int y, int index, QPainter& painter);
+
+        void startDrag(int index);
+        void drawDropIndicator(int index, bool disabled = false);
+        int dropIndex(const QPoint pos);
+        bool isSameTab(const QDropEvent*);
 
         MainWindow* m_mainWindow;
         Skin* m_skin;
@@ -110,10 +134,11 @@ class TabBar : public QWidget
         KPushButton* m_closeTabButton;
 
         KMenu* m_tabContextMenu;
+        KMenu* m_toggleKeyboardInputMenu;
         KMenu* m_sessionMenu;
 
         KLineEdit* m_lineEdit;
-        int m_editingSessionId;
+        int m_renamingSessionId;
 
         QList<int> m_tabs;
         QHash<int, QString> m_tabTitles;
@@ -123,6 +148,10 @@ class TabBar : public QWidget
 
         int m_mousePressed;
         int m_mousePressedIndex;
+
+        QPoint m_startPos;
+        QLabel* m_dropIndicator;
+        QRect m_dropRect;
 };
 
 #endif
